@@ -47,9 +47,9 @@ set( 'DISPATCH_RESOURCES_INTERVAL', {
     'interval/eid/:eid/:tsrange' => 
     {
         target => {
-            GET => '_fetch_by_eid',
+            GET => 'fetch_by_eid',
         },
-        target_module => 'App::Dochazka::REST::Dispatch::Interval',
+        target_module => 'App::Dochazka::REST::Dispatch::Shared',
         acl_profile => 'admin', 
         cli => 'interval eid $EID $TSRANGE',
         description => 'Retrieve an arbitrary employee\'s intervals over the given tsrange',
@@ -85,9 +85,9 @@ EOH
     'interval/iid' => 
     {
         target => {
-            POST => '_iid',
+            POST => 'iid_lid',
         },
-        target_module => 'App::Dochazka::REST::Dispatch::Interval',
+        target_module => 'App::Dochazka::REST::Dispatch::Shared',
         acl_profile => 'active', 
         cli => 'interval iid $JSON',
         description => 'Update an existing interval object via POST request (iid must be included in request body)',
@@ -103,11 +103,11 @@ EOH
     'interval/iid/:iid' => 
     {
         target => {
-            GET => '_iid',
-            PUT => '_iid',
-            DELETE => '_iid',
+            GET => 'iid_lid',
+            PUT => 'iid_lid',
+            DELETE => 'iid_lid',
         },
-        target_module => 'App::Dochazka::REST::Dispatch::Interval',
+        target_module => 'App::Dochazka::REST::Dispatch::Shared',
         acl_profile => {
             GET => 'active',
             PUT => 'active',
@@ -162,9 +162,9 @@ EOH
     'interval/nick/:nick/:tsrange' => 
     {
         target => {
-            GET => '_fetch_by_nick',
+            GET => 'fetch_by_nick',
         },
-        target_module => 'App::Dochazka::REST::Dispatch::Interval',
+        target_module => 'App::Dochazka::REST::Dispatch::Shared',
         acl_profile => 'admin', 
         cli => 'interval nick $NICK $TSRANGE',
         description => 'Retrieve an arbitrary employee\'s intervals over the given tsrange',
@@ -181,9 +181,9 @@ EOH
     'interval/self/:tsrange' => 
     {
         target => {
-            GET => '_fetch_own',
+            GET => 'fetch_own',
         },
-        target_module => 'App::Dochazka::REST::Dispatch::Interval',
+        target_module => 'App::Dochazka::REST::Dispatch::Shared',
         acl_profile => 'inactive', 
         cli => 'interval self $TSRANGE',
         description => 'Retrieve one\'s own intervals over the given tsrange',
