@@ -60,11 +60,11 @@ the data model
 
 =head1 VERSION
 
-Version 0.292
+Version 0.298
 
 =cut
 
-our $VERSION = '0.292';
+our $VERSION = '0.298';
 
 
 
@@ -152,7 +152,7 @@ sub make_test_exists {
         if ( ! defined( $status ) or $status->level eq 'CRIT' ) {
             die $txt;
         }
-        $log->debug( "Status is " . Dumper( $status ) );
+        #$log->debug( "Status is " . Dumper( $status ) );
         return $status->payload if $status->ok;
         return;
     }
